close all
% caoutchouc
E = 21e5; nu = 0.45; %nu = 0.28; 
mu= E/(2*(1+nu));
lambda = E*nu/((1+nu)*(1-2*nu));
N=5;
f=@(x,y,z) -200+-500*(( (x>4)&(x<6) ).*( (y>4) & (y<6) ) );
dim=3;
%  
[geodir,meshdir]=fc_vfemp1.default_directories(dim);
geofile='platewith4holes';

fprintf('------------------------------------------------------\n'); 
fprintf('      3D elasticity BVP on a plate with 4 cylinder holes\n\n');
fprintf('             -div(sigma(u)) = f \n');
fprintf(' and boundary conditions :\n');
fprintf('   * Dirichlet on [2,4]\n');
fprintf('       u_1 = u_2 = u_3 = 0 on [2,4],\n');
fprintf('   * Neumann on all the others\n');
fprintf('       sigma(u).n = 0 on [1,3,5,6,10:13]\n');
fprintf(' with f=(0,0,fz)^t, lambda=%g, mu=%g\n',lambda,mu);
fprintf('      and fz=%s\n',func2str(f));
fprintf('------------------------------------------------------\n'); 

fprintf('1. Building the mesh using gmsh with %s.geo file\n',geofile);
meshfile=gmsh.buildmesh(geofile,N,'d',3,'geodir',geodir,'meshdir',meshdir);%,'force',true)
Th=siMesh(meshfile,'dim',3,'format','gmsh');
fprintf('     Mesh sizes : nq=%d, nme=%d, h=%.3e\n',Th.nq,Th.get_nme(),Th.get_h());

fprintf('2.a Setting 3D elasticity BVP\n');
%Hop=Hoperator.StiffElas(dim,lam,mu);
gamma=lambda+2*mu;
Hop=Hoperator(dim,dim,dim);
Hop.opStiffElas(dim,lambda,mu);
pde=PDEelt(Hop,{0,0,f});
bvp=BVP(Th,pde);
bvp.setDirichlet(2,0.,1:3);
bvp.setDirichlet(4,0.,1:3);
fprintf('2.b Solving 3D elasticity BVP\n')
U=bvp.solve('split',true);

fprintf('3. Graphic representations\n');
options=fc_tools.graphics.DisplayFigures('nfig',5);
interpreter=@(x) fc_tools.graphics.interpreter(x);

figure(1)
Th.plotmesh('d',2,'legend',true,'EdgeColor','None')
hold on,axis image,axis off
set(legend(),options.legend{:})
title(interpreter(sprintf('$n_q=%d$, $n_{me}=%d$',Th.nq,Th.get_nme())),options.interpreter{:},options.title{:});

figure(2)
Th.plotmesh('d',2,'legend',true,'EdgeColor','None','labels',[1:4,6,10:13])%setdiff(Th.sThlab(Th.find(2)),5))
hold on,axis image,axis off
set(legend(),options.legend{:})
title(interpreter(sprintf('$n_q=%d$, $n_{me}=%d$',Th.nq,Th.get_nme())),options.interpreter{:},options.title{:});

scale=50;
idx=Th.find(3); % for this mesh, only 1 elt
sTh=Th.sTh{idx}.copy();
sTh.q=sTh.q+scale*[U{1}';U{2}';;U{3}'];

figure(3)
sTh.plotmesh('color','b')
axis off, axis image
title(sprintf('Mesh displacement scaled by %d',scale),options.title{:});
hold on

v=sqrt(U{1}.^2+U{2}.^2+U{3}.^2);
isorange=[linspace(min(v),0.009,10),linspace(0.01,max(v),5)];
figure(4);
P1=fc_tools.graphics.PlaneCoefs([5 5 0],[0 0 1]);
Th.sliceiso(v,P1,'isorange',isorange)
%Th.slice(v,P1, 'FaceColor','interp', 'EdgeColor','none')
hold on
caxis([min(v),max(v)])
%Th.sliceiso(v,P1,'isorange',isorange, 'color','w')
P2=fc_tools.graphics.PlaneCoefs([5 5 0],[0 1 0]);
Th.slice(v,P2, 'FaceColor','interp', 'EdgeColor','none')
Th.sliceiso(v,P2,'isorange',isorange, 'color','w')
Th.plot(v,'d',2,'labels',[1,3,10:13], 'FaceColor','interp', 'EdgeColor','none')
Th.plotiso(v,'labels',[1,3,10:13], 'isorange',isorange, 'color','w')
%  Th.plot(v,'d',2,'labels',[10:13], 'FaceColor','interp', 'EdgeColor','none')
%  Th.plotiso(v,'labels',[1,3], 'isorange',isorange, 'color','w')
axis off,axis image
%  view(-114,11)
set(colorbar(),options.colorbar{:})

figure(5);
P1=fc_tools.graphics.PlaneCoefs([5 5 0],[0 0 1]);
Th.slice(v,P1, 'FaceColor','interp', 'EdgeColor','none')
hold on
caxis([min(v),max(v)])
Th.sliceiso(v,P1,'isorange',isorange, 'color','w')
P2=fc_tools.graphics.PlaneCoefs([5 5 0],[0 1 0]);
Th.slice(v,P2, 'FaceColor','interp', 'EdgeColor','none')
Th.sliceiso(v,P2,'isorange',isorange, 'color','w')
Th.plot(v,'d',2,'labels',[1,3], 'FaceColor','interp', 'EdgeColor','none')
Th.plotiso(v,'labels',[1,3], 'isorange',isorange, 'color','w')
Th.plot(v,'d',2,'labels',[10:13], 'FaceColor','none', 'EdgeColor','interp')
Th.plotiso(v,'labels',[10:13], 'isorange',isorange, 'color','w')
axis off,axis image
set(colorbar(),options.colorbar{:})





