function [bvp,info]=setBVPStationaryConvectionDiffusion3D01(N,varargin)
  [default_geodir,default_meshdir]=fc_vfemp1.default_directories(3);
  p = inputParser; 
  p.addParameter('verbose',0,@isscalar); 
  p.addParamValue('geodir',default_geodir,@ischar); 
  p.addParamValue('meshdir',default_meshdir,@ischar);
  p.parse(varargin{:});
  R=p.Results;verbose=R.verbose;
  geofile='cylinder3holes';  
  af=@(x,y,z) 0.7+ z/10;
  beta=0.01;
  V={@(x,y,z) -10*y ,@(x,y,z) 10*x ,@(x,y,z) 10*z};
  f=@(x,y,z) -800*exp(-10*((x-0.65).^2+y.^2+(z-0.5).^2)) + 800*exp(-10*((x+0.65).^2+y.^2+(z-0.5).^2));
  if verbose>=1
     fprintf('------------------------------------------------------\n'); 
    fprintf('      3D stationary convection-diffusion BVP\n');
    fprintf('         on GMSH mesh from %s.geo\n',geofile);
    fprintf('               - div(a grad u) + <V,grad u> + b u = f\n')
    fprintf(' and boundary conditions :\n');
    fprintf('   * Neumann on [2,4,20,21]\n');
    fprintf('       du/dn = 0   \n');
    fprintf('   * Robin on [20,21]\n');
    fprintf('       du/dn + u = +0.05 on [20]\n');
    fprintf('       du/dn + u = -0.05 on [21]\n');
    fprintf(' with \n');
    fprintf('   a = %s \n',func2str(af));
    fprintf('   V = [%s,%s,%s] \n',func2str(V{1}),func2str(V{2}),func2str(V{3}));
    fprintf('   b = %g \n',beta);
    fprintf('   f = %s \n',func2str(f));
    fprintf('------------------------------------------------------\n');
    if verbose==10, return;end
  end

  if verbose>=2,fprintf('1. Building the mesh using GMSH\n');end
  tstart=tic();
  meshfile=gmsh.buildmesh3d(geofile,N,'geodir',R.geodir,'meshdir',R.meshdir);%,'force',true);
  Th=siMesh(meshfile);
  
  tcpu(1)=toc(tstart);
  if verbose>=2
    fprintf('     Mesh sizes : nq=%d, nme=%d, h=%.3e\n',Th.nq,Th.get_nme(),Th.get_h());
    fprintf('2. Setting 3D stationary convection-diffusion BVP\n');
  end
  tstart=tic();
  Lop=Loperator(Th.dim,Th.d,{af,[],[];[],af,[];[],[],af},[],V,beta);
  pde=PDEelt(Lop,f);
  bvp=BVP(Th,pde);
  bvp.setRobin(20,0.05,1);
  bvp.setRobin(21,-0.05,1);
  tcpu(2)=toc(tstart);

  info.solex=[];
  info.V=V;
  info.f=f;
  info.tcpu=tcpu;
end